@@ -113,6 +113,18 @@ def INPUT(text,x,y,NOENTER=False, NPRINT=False):
                 pass
             else:
                 pass
+            if key == Fr'\x9c':
+                try:
+                    f.write(u"\xa3")
+                except:
+                    pass
+            elif key == 'Â':
+                pass
+            else:
+                try:
+                    f.write(F"{key}")
+                except:
+                    pass
             if PRINT == True:
                 print(key)
                 break
